MatrixAddress

Struct MatrixAddress 

pub struct MatrixAddress {
    pub x: i32,
    pub y: i32,
}

Fields

x: i32y: i32

Implementations

Source

impl MatrixAddress

pub fn scale(self, scalar: f64) -> Self

Scales the position of the matrix address by the floating point scalar. Epsilon is added to the results before truncation to avoid floating point precision issues

Arguments
  • scalar: The scalar to multiply the value with.

Returns: MatrixAddress

Examples
use rust_tensors::matrix_address::MatrixAddress;
let address = MatrixAddress {x: 5, y: 10};
assert_eq!(address.scale(0.5), MatrixAddress {x: 2, y: 5});