pub struct MatrixAddress {
pub x: i32,
pub y: i32,
}Fields
x: i32y: i32Implementations
Sourceimpl MatrixAddress
impl MatrixAddress
Sourcepub fn scale(self, scalar: f64) -> Self
pub fn scale(self, scalar: f64) -> Self
Scales the position of the matrix address by the floating point scalar. Epsilon is added to the results before truncation to avoid floating point precision issues
Arguments
scalar: The scalar to multiply the value with.
Returns: MatrixAddress
Examples
use rust_tensors::matrix_address::MatrixAddress;
let address = MatrixAddress {x: 5, y: 10};
assert_eq!(address.scale(0.5), MatrixAddress {x: 2, y: 5});Trait Implementations
Sourceimpl Add for MatrixAddress
impl Add for MatrixAddress
Sourceimpl Addressable<i32, 2> for MatrixAddress
impl Addressable<i32, 2> for MatrixAddress
fn get_value_at_dimension_index(&self, index: usize) -> i32
Sourceimpl Clone for MatrixAddress
impl Clone for MatrixAddress
Sourcefn clone(&self) -> MatrixAddress
fn clone(&self) -> MatrixAddress
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for MatrixAddress
Sourceimpl Debug for MatrixAddress
impl Debug for MatrixAddress
impl Eq for MatrixAddress
Sourceimpl<T> Index<MatrixAddress> for Matrix<T>
impl<T> Index<MatrixAddress> for Matrix<T>
Sourceimpl<T> IndexMut<MatrixAddress> for Matrix<T>
impl<T> IndexMut<MatrixAddress> for Matrix<T>
Sourceimpl Neg for MatrixAddress
impl Neg for MatrixAddress
Sourceimpl PartialEq for MatrixAddress
impl PartialEq for MatrixAddress
Sourcefn eq(&self, other: &MatrixAddress) -> bool
fn eq(&self, other: &MatrixAddress) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for MatrixAddress
Sourceimpl Sub for MatrixAddress
impl Sub for MatrixAddress
Sourceimpl<T> Tensor<T, i32, MatrixAddress, 2> for Matrix<T>
impl<T> Tensor<T, i32, MatrixAddress, 2> for Matrix<T>
fn smallest_contained_address(&self) -> MatrixAddress
fn largest_contained_address(&self) -> MatrixAddress
Sourcefn get(&self, address: A) -> Result<&T, String>
fn get(&self, address: A) -> Result<&T, String>
Attempts to get a reference of the value at the given address. Will return Err if the address
is not contained in the matrix. Read more
Sourcefn get_mut(&mut self, address: A) -> Result<&mut T, String>
fn get_mut(&mut self, address: A) -> Result<&mut T, String>
Attempts to get a mutable reference of the value at the given address. Will return Err if the
address is not contained in the matrix. Read more
Sourcefn contains_address(&self, address: A) -> bool
fn contains_address(&self, address: A) -> bool
Evaluates whether an address is valid and has an associated value in the tensor. Read more
Sourcefn address_iter(&self) -> AddressIterator<V, A, DIMENSION>
fn address_iter(&self) -> AddressIterator<V, A, DIMENSION>
Creates an iterator over the addresses within the bounds of the tensor. Read more